@@ -3,26 +3,35 @@
 /*     Master list of function prototypes				*/
 /*----------------------------------------------------------------------*/
 
-/* from tclxcircuit.c */
+/* from tclxcircuit.c: */
 
 #ifdef TCL_WRAPPER
+
 extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
-extern Tcl_Obj *evaluate_raw(oparamptr);
-extern char *TCL_to_PS(char *);
-#endif
+extern objectptr NameToObject(char *, objinstptr *, Boolean);
 
-extern char *evaluate_expr(oparamptr);
+#endif /* TCL_WRAPPER */
+
+/* from the ASG module: */
+
+#ifdef ASG
+
+extern int asg_make_instance(Clientdata, char*, float, float, int, int, float);
+extern void asg_make_polygon(Clientdata, int, int x[], int y[]);
+extern void asg_make_label(Clientdata, u_char, int, int, char *);
+extern void importivf();
+extern void importspice();
+
+#endif /* ASG */
 
 /* from elements.c: */
 
-extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
 extern void objectdefaults(objinstptr, objectptr, int, int);
 extern void labeldefaults(labelptr, u_char, int, int);
-extern void poly_add_point(polyptr, XPoint *);
 extern void polydefaults(polyptr, int, int, int);
 extern void splinedefaults(splineptr, int, int);
 extern void arcdefaults(arcptr, int, int);
@@ -89,7 +98,6 @@ extern void panrefresh(u_int, XButtonEvent *);
 extern void centerpan(xcWidget, caddr_t, caddr_t);
 extern void checkwarp(XPoint *);
 extern int checkcycle(short, short);
-extern void copyvirtual();
 extern void nextpolycycle(polyptr, short);
 extern void nextsplinecycle(splineptr, short);
 extern void nextarccycle(arcptr, short);
@@ -171,7 +179,7 @@ extern int lookdirectory(char *);
 
 /* from files.c: */
 
-extern char *ridnewline(char *);
+extern void ridnewline(char *);
 extern void free_single(genericptr *);
 extern void reset(objectptr, short);
 extern void pagereset(short);
@@ -183,10 +191,9 @@ extern short objcompare(objectptr, objectptr);
 extern float getpsscale(float, short);
 extern void dostcount(FILE *, short *, short);
 extern short printparams(FILE *, objinstptr, short);
-extern void printobjectparams(FILE *, objectptr);
 extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
 extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
-extern void varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
+extern void varpcheck(FILE *, short, objectptr, int, int, short *, genericptr, u_char);
 extern void getfile(xcWidget, pointertype, caddr_t);
 extern Boolean nextfilename();
 extern void loadfontlib();
@@ -200,7 +207,6 @@ extern void startloadfile();
 extern void importfile();
 extern void loadfile(short);
 extern void readlabel(objectptr, char *, stringpart **);
-extern void readparams(objectptr, objinstptr, objectptr, char *);
 extern u_char *find_match(u_char *);
 extern char *advancetoken(char *);
 extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
@@ -225,10 +231,8 @@ extern Boolean xc_tilde_expand(char *);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
 extern void writelabelsegs(FILE *, short *, stringpart *);
-extern void printobjects(FILE *, objectptr, objectptr **, short *, int);
-extern void printrefobjects(FILE *, objectptr, objectptr **, short *);
-extern void printpageobject(FILE *, objectptr, short, short);
-
+extern void printobjects(FILE *, objectptr, float, float, float, short, short,
+                         objectptr **, short *, int);
 
 /* from fontfile.c: */
 
@@ -255,7 +259,6 @@ extern void findsplinepos(splineptr, float, XPoint *, int *);
 extern void ffindsplinepos(splineptr, float, XfPoint *);
 extern float findsplinemin(splineptr, XPoint *);
 extern short closepoint(polyptr, XPoint *);
-extern void updateinstparam(objectptr);
 extern short checkbounds();
 extern void window_to_user(short, short, XPoint *);
 extern void user_to_window(XPoint, XPoint *);
@@ -305,8 +308,8 @@ extern void UDrawCircle(XPoint *, u_char);
 extern void UDrawX(labelptr);
 #ifdef SCHEMA
 extern void UDrawXDown(labelptr);
-extern int  toplevelwidth(objinstptr, short *);
-extern int  toplevelheight(objinstptr, short *);
+extern int  toplevelwidth(objinstptr);
+extern int  toplevelheight(objinstptr);
 extern void extendschembbox(objinstptr, XPoint *, XPoint *);
 #endif
 extern void pinadjust(short, short *, short *, short);
@@ -323,7 +326,6 @@ extern void UDrawPolygon(polyptr);
 extern void UDrawArc(arcptr);
 extern void UDrawPath(pathptr);
 extern void UDrawObject(objinstptr, short, int, pushlistptr *);
-extern void TopDoLatex();
 
 /* from help.c: */
 
@@ -419,9 +421,7 @@ extern void makenewencodingbutton(char *, char);
 extern void togglefontmark(int);
 #ifndef TCL_WRAPPER
 extern void toggleexcl(xcWidget, menuptr, int);
-extern void promptparam(xcWidget, caddr_t, caddr_t);
 #endif
-extern void stringparam(xcWidget, caddr_t, caddr_t);
 extern void toggle(xcWidget, Boolean *, caddr_t);
 extern void setcolorscheme(Boolean);
 extern void inversecolor(xcWidget, Boolean *, caddr_t);
@@ -455,11 +455,13 @@ extern void setfontmarks(short, short);
 extern void startparam(xcWidget, pointertype, caddr_t);
 extern void startunparam(xcWidget, pointertype, caddr_t);
 extern void setdefaultfontmarks();
-extern void setjustbit(xcWidget, pointertype, caddr_t);
-extern void setpinjustbit(xcWidget, pointertype, caddr_t);
+extern void dopinvisible(xcWidget, labelptr);
+extern void doflipflip(xcWidget, labelptr);
 extern void setjust(xcWidget, pointertype, labelptr, short);
 extern void setvjust(xcWidget, pointertype, caddr_t);
 extern void sethjust(xcWidget, pointertype, caddr_t);
+extern void setflipinv(xcWidget, pointertype, caddr_t);
+extern void setpinvisible(xcWidget, pointertype, caddr_t);
 extern void boxedit(xcWidget, pointertype, caddr_t);
 extern void locloadfont(xcWidget, char *);
 extern void addnewfont(xcWidget, caddr_t, caddr_t);
@@ -476,18 +478,14 @@ extern void border_popup(xcWidget, caddr_t, caddr_t);
 extern void color_popup(xcWidget, caddr_t, caddr_t);
 extern void fill_popup(xcWidget, caddr_t, caddr_t);
 extern void param_popup(xcWidget, caddr_t, caddr_t);
-extern Boolean dospecial(void);
+extern void dospecial(void);
 
 /* from netlist.c: */
 
 #ifdef SCHEMA
-extern Boolean RemoveFromNetlist(objectptr, genericptr);
-extern labelptr NetToLabel(int, objectptr);
-extern void NameToPosition(objinstptr, labelptr, XPoint *);
-extern void invalidate_netlist(objectptr);
-extern int updatenets(objinstptr);
-extern void createnets(objinstptr);
+extern void createnets();
 extern void destroynets();
+extern void gennet(char *, char *);
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
 extern void gennetlist(objectptr, objinstptr);
@@ -525,54 +523,37 @@ extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
 extern void writehierarchy(objectptr, CalllistPtr, FILE *);
 extern void writenet(objectptr, char *, char *);
-extern void writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
-extern void outputpcb(struct Ptab *, FILE *);
-extern void freepcb(struct Ptab *);
-extern void freepolylist(NetlistPtr);
-extern void freelabellist(NetlistPtr);
-extern void freeports(CalllistPtr);
+extern void writepcb(objectptr, CalllistPtr, char *, char *);
+extern void outputpcb(objectptr, FILE *);
+extern void freepcb();
 extern void freenets(objectptr);
 extern void freetemplabels(objectptr);
 extern void freeglobals();
-extern int cleartraversed(objectptr);
+extern int cleartraversed(objectptr, int);
 extern int checkvalid(objectptr);
 extern void clearpins(objectptr);
 #endif
 
 /* from parameter.c: */ 
 
-extern char *find_indirect_param(objinstptr, char *);
-extern oparamptr match_param(objectptr, char *);
-extern oparamptr match_instance_param(objinstptr, char *);
-extern oparamptr find_param(objinstptr, char *);
-extern int get_num_params(objectptr);
-extern void free_object_param(objectptr, oparamptr);
-extern void free_instance_param(objinstptr, oparamptr);
-extern void free_element_param(genericptr, eparamptr);
-
-extern oparamptr make_new_parameter(char *);
-extern eparamptr make_new_eparam(char *);
-
-extern void makeexprparam(objectptr, char *, char *, int);
-extern void makefloatparam(objectptr, char *, float);
-extern void makestringparam(objectptr, char *, stringpart *);
 extern void indicateparams(genericptr);
-extern void makenumericalp(genericptr *, u_int, char *);
+extern void makenumericalp(genericptr *, u_int);
+extern void unmakenumericalp(genericptr *, u_int);
 extern void noparmstrcpy(u_char *, u_char *);
 extern void insertparam();
-extern void makeparam(labelptr, char *);
-extern void searchinst(objectptr, objectptr, char *);
+extern void makeparam(labelptr);
+extern void initinst(objectptr, objectptr, short);
+extern void searchinst(objectptr, objectptr, short);
+extern void initallinstances(objectptr, int);
 extern stringpart *searchparam(stringpart *);
 extern void unmakeparam(labelptr, stringpart *);
-extern void unmakenumericalp(genericptr *, u_int);         
 extern void unparameterize(int);
-extern void parameterize(int, char *);
+extern void parameterize(int);
 extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
 extern int opsubstitute(objectptr, objinstptr);
 extern int psubstitute(objinstptr);
-extern oparamptr copyparameter(oparamptr);
 extern void pwriteback(objinstptr);
 extern short paramlen(u_char *);
 extern int natstrlen(u_char *);
@@ -627,8 +608,7 @@ extern int reset_gs();
 
 /* from schema.c: */
 
-extern objectptr NameToObject(char *, objinstptr *, Boolean);
-extern void callwritenet(xcWidget, pointertype, caddr_t);
+extern void callgennet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
 extern void startconnect(xcWidget, caddr_t, caddr_t);
 extern int connectivity(xcWidget, caddr_t, caddr_t);
